@@ -21,7 +21,7 @@ import inspect
 from json import JSONDecodeError
 from os.path import dirname
 from typing import TYPE_CHECKING, cast
-from unittest.mock import Mock, patch
+from unittest.mock import Mock
 
 import pytest
 from httpx import Response
@@ -52,6 +52,7 @@ from unit.microsoft.azure.test_utils import (
     mock_connection,
     mock_json_response,
     mock_response,
+    patch_hook,
 )
 
 if TYPE_CHECKING:
@@ -62,16 +63,6 @@ if TYPE_CHECKING:
         AzureIdentityAccessTokenProvider,
     )
 
-try:
-    import importlib.util
-
-    if not importlib.util.find_spec("airflow.sdk.bases.hook"):
-        raise ImportError
-
-    BASEHOOK_PATCH_PATH = "airflow.sdk.bases.hook.BaseHook"
-except ImportError:
-    BASEHOOK_PATCH_PATH = "airflow.hooks.base.BaseHook"
-
 
 class TestKiotaRequestAdapterHook:
     @staticmethod
@@ -90,102 +81,99 @@ class TestKiotaRequestAdapterHook:
         assert tenant_id == expected_tenant_id
 
     def test_get_conn(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
-            actual = hook.get_conn()
+
+            with pytest.warns(
+                DeprecationWarning,
+                match="get_conn is deprecated, please use the async get_async_conn method!",
+            ):
+                actual = hook.get_conn()
 
             assert isinstance(actual, HttpxRequestAdapter)
             assert actual.base_url == "https://graph.microsoft.com/v1.0/"
 
-    def test_get_conn_with_custom_base_url(self):
-        connection = lambda conn_id: get_airflow_connection(
-            conn_id=conn_id,
-            host="api.fabric.microsoft.com",
-            api_version="v1",
-        )
+    @pytest.mark.asyncio
+    async def test_get_async_conn(self):
+        with patch_hook():
+            hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
+            actual = await hook.get_async_conn()
 
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=connection,
+            assert isinstance(actual, HttpxRequestAdapter)
+            assert actual.base_url == "https://graph.microsoft.com/v1.0/"
+
+    @pytest.mark.asyncio
+    async def test_get_async_conn_with_custom_base_url(self):
+        with patch_hook(
+            side_effect=lambda conn_id: get_airflow_connection(
+                conn_id=conn_id,
+                host="api.fabric.microsoft.com",
+                api_version="v1",
+            )
         ):
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
-            actual = hook.get_conn()
+            actual = await hook.get_async_conn()
 
             assert isinstance(actual, HttpxRequestAdapter)
             assert actual.base_url == "https://api.fabric.microsoft.com/v1/"
 
-    def test_get_conn_with_proxies_as_string(self):
-        connection = lambda conn_id: get_airflow_connection(
-            conn_id=conn_id,
-            host="api.fabric.microsoft.com",
-            api_version="v1",
-            proxies="{'http': 'http://proxy:80', 'https': 'https://proxy:80'}",
-        )
-
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=connection,
+    @pytest.mark.asyncio
+    async def test_get_async_conn_with_proxies_as_string(self):
+        with patch_hook(
+            side_effect=lambda conn_id: get_airflow_connection(
+                conn_id=conn_id,
+                host="api.fabric.microsoft.com",
+                api_version="v1",
+                proxies="{'http': 'http://proxy:80', 'https': 'https://proxy:80'}",
+            )
         ):
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
-            actual = hook.get_conn()
+            actual = await hook.get_async_conn()
 
             assert isinstance(actual, HttpxRequestAdapter)
             assert actual._http_client._mounts.get(URLPattern("http://"))
             assert actual._http_client._mounts.get(URLPattern("https://"))
 
-    def test_get_conn_with_proxies_as_invalid_string(self):
-        connection = lambda conn_id: get_airflow_connection(
-            conn_id=conn_id,
-            host="api.fabric.microsoft.com",
-            api_version="v1",
-            proxies='["http://proxy:80", "https://proxy:80"]',
-        )
-
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=connection,
+    @pytest.mark.asyncio
+    async def test_get_async_conn_with_proxies_as_invalid_string(self):
+        with patch_hook(
+            side_effect=lambda conn_id: get_airflow_connection(
+                conn_id=conn_id,
+                host="api.fabric.microsoft.com",
+                api_version="v1",
+                proxies='["http://proxy:80", "https://proxy:80"]',
+            )
         ):
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
 
             with pytest.raises(AirflowConfigException):
-                hook.get_conn()
+                await hook.get_async_conn()
 
-    def test_get_conn_with_proxies_as_json(self):
-        connection = lambda conn_id: get_airflow_connection(
-            conn_id=conn_id,
-            host="api.fabric.microsoft.com",
-            api_version="v1",
-            proxies='{"http": "http://proxy:80", "https": "https://proxy:80"}',
-        )
-
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=connection,
+    @pytest.mark.asyncio
+    async def test_get_async_conn_with_proxies_as_json(self):
+        with patch_hook(
+            side_effect=lambda conn_id: get_airflow_connection(
+                conn_id=conn_id,
+                host="api.fabric.microsoft.com",
+                api_version="v1",
+                proxies='{"http": "http://proxy:80", "https": "https://proxy:80"}',
+            )
         ):
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
-            actual = hook.get_conn()
+            actual = await hook.get_async_conn()
 
             assert isinstance(actual, HttpxRequestAdapter)
             assert actual._http_client._mounts.get(URLPattern("http://"))
             assert actual._http_client._mounts.get(URLPattern("https://"))
 
     def test_scopes_when_default(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
 
             assert hook.scopes == [KiotaRequestAdapterHook.DEFAULT_SCOPE]
 
     def test_scopes_when_passed_as_string(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(
                 conn_id="msgraph_api", scopes="https://microsoft.sharepoint.com/.default"
             )
@@ -193,10 +181,7 @@ class TestKiotaRequestAdapterHook:
             assert hook.scopes == ["https://microsoft.sharepoint.com/.default"]
 
     def test_scopes_when_passed_as_list(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(
                 conn_id="msgraph_api", scopes=["https://microsoft.sharepoint.com/.default"]
             )
@@ -204,49 +189,40 @@ class TestKiotaRequestAdapterHook:
             assert hook.scopes == ["https://microsoft.sharepoint.com/.default"]
 
     def test_api_version(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
-            hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
+        with patch_hook():
+            hook = KiotaRequestAdapterHook(conn_id="msgraph_api", api_version=APIVersion.v1.value)
 
             assert hook.api_version == APIVersion.v1.value
 
+    def test_api_version_when_none_is_explicitly_passed_as_api_version(self):
+        with patch_hook():
+            hook = KiotaRequestAdapterHook(conn_id="msgraph_api", api_version=None)
+
+            assert not hook.api_version
+
     def test_get_api_version_when_empty_config_dict(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
             actual = hook.get_api_version({})
 
             assert actual == APIVersion.v1.value
 
     def test_get_api_version_when_api_version_in_config_dict(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
             actual = hook.get_api_version({"api_version": "beta"})
 
             assert actual == APIVersion.beta.value
 
     def test_get_api_version_when_custom_api_version_in_config_dict(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api", api_version="v1")
             actual = hook.get_api_version({})
 
             assert actual == "v1"
 
     def test_get_host_when_connection_has_scheme_and_host(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
             connection = mock_connection(schema="https", host="graph.microsoft.de")
             actual = hook.get_host(connection)
@@ -254,38 +230,31 @@ class TestKiotaRequestAdapterHook:
             assert actual == NationalClouds.Germany.value
 
     def test_get_host_when_connection_has_no_scheme_or_host(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
             connection = mock_connection()
             actual = hook.get_host(connection)
 
             assert actual == NationalClouds.Global.value
 
-    def test_tenant_id(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+    @pytest.mark.asyncio
+    async def test_tenant_id(self):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
-            actual = hook.get_conn()
+            actual = await hook.get_async_conn()
 
             self.assert_tenant_id(actual, "tenant-id")
 
-    def test_azure_tenant_id(self):
-        airflow_connection = lambda conn_id: get_airflow_connection(
-            conn_id=conn_id,
-            azure_tenant_id="azure-tenant-id",
-        )
-
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=airflow_connection,
+    @pytest.mark.asyncio
+    async def test_azure_tenant_id(self):
+        with patch_hook(
+            side_effect=lambda conn_id: get_airflow_connection(
+                conn_id=conn_id,
+                azure_tenant_id="azure-tenant-id",
+            )
         ):
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
-            actual = hook.get_conn()
+            actual = await hook.get_async_conn()
 
             self.assert_tenant_id(actual, "azure-tenant-id")
 
@@ -296,20 +265,18 @@ class TestKiotaRequestAdapterHook:
 
         assert actual == {"%24expand": "reports,users,datasets,dataflows,dashboards", "%24top": 5000}
 
-    def test_request_information_with_custom_host(self):
-        connection = lambda conn_id: get_airflow_connection(
-            conn_id=conn_id,
-            host="api.fabric.microsoft.com",
-            api_version="v1",
-        )
-
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=connection,
+    @pytest.mark.asyncio
+    async def test_request_information_with_custom_host(self):
+        with patch_hook(
+            side_effect=lambda conn_id: get_airflow_connection(
+                conn_id=conn_id,
+                host="api.fabric.microsoft.com",
+                api_version="v1",
+            )
         ):
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
             request_info = hook.request_information(url="myorg/admin/apps", query_parameters={"$top": 5000})
-            request_adapter = hook.get_conn()
+            request_adapter = await hook.get_async_conn()
             request_adapter.set_base_url_for_request_information(request_info)
 
             assert isinstance(request_info, RequestInformation)
@@ -318,10 +285,7 @@ class TestKiotaRequestAdapterHook:
 
     @pytest.mark.asyncio
     async def test_throw_failed_responses_with_text_plain_content_type(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
             response = Mock(spec=Response)
             response.headers = {"content-type": "text/plain"}
@@ -330,17 +294,15 @@ class TestKiotaRequestAdapterHook:
             response.is_success = False
             span = Mock(spec=Span)
 
-            actual = await hook.get_conn().get_root_parse_node(response, span, span)
+            conn = await hook.get_async_conn()
+            actual = await conn.get_root_parse_node(response, span, span)
 
             assert isinstance(actual, TextParseNode)
             assert actual.get_str_value() == "TenantThrottleThresholdExceeded"
 
     @pytest.mark.asyncio
     async def test_throw_failed_responses_with_application_json_content_type(self):
-        with patch(
-            f"{BASEHOOK_PATCH_PATH}.get_connection",
-            side_effect=get_airflow_connection,
-        ):
+        with patch_hook():
             hook = KiotaRequestAdapterHook(conn_id="msgraph_api")
             response = Mock(spec=Response)
             response.headers = {"content-type": "application/json"}
@@ -349,7 +311,8 @@ class TestKiotaRequestAdapterHook:
             response.is_success = False
             span = Mock(spec=Span)
 
-            actual = await hook.get_conn().get_root_parse_node(response, span, span)
+            conn = await hook.get_async_conn()
+            actual = await conn.get_root_parse_node(response, span, span)
 
             assert isinstance(actual, JsonParseNode)
             error_code = actual.get_child_node("error").get_child_node("code").get_str_value()
